==> haskell-rsa-2.4.1-232-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-rsa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 RSA
version:              2.4.1
visibility:           public
id:                   RSA-2.4.1-BVV6eOSj6o4L91De7WHCzc
key:                  RSA-2.4.1-BVV6eOSj6o4L91De7WHCzc
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@galois.com>
author:               Adam Wick <awick@galois.com>
stability:            stable
synopsis:
    Implementation of RSA, using the padding schemes of PKCS#1 v2.1.

description:
    This library implements the RSA encryption and signature
    algorithms for arbitrarily-sized ByteStrings. While the
    implementations work, they are not necessarily the fastest ones
    on the planet. Particularly key generation. The algorithms
    included are based of RFC 3447, or the Public-Key Cryptography
    Standard for RSA, version 2.1 (a.k.a, PKCS#1 v2.1).

category:             Cryptography, Codec
abi:                  37dcba1fb866cc9d651014dd09453af8
exposed:              True
exposed-modules:
    Codec.Crypto.RSA Codec.Crypto.RSA.Exceptions Codec.Crypto.RSA.Pure

import-dirs:          /usr/lib/ghc-9.2.8/site-local/RSA-2.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/RSA-2.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rsa
hs-libraries:         HSRSA-2.4.1-BVV6eOSj6o4L91De7WHCzc
depends:
    SHA-1.6.4.4-4vZ3YEU9upt6TqgW7hflaa base-4.16.4.0 binary-0.8.9.0
    bytestring-0.11.4.0 crypto-api-0.13.3-95IFBy4WvL6L3p6UFm5MLc
    crypto-pubkey-types-0.4.3-FODgSNFAve39E65iS9QFGb

haddock-interfaces:   /usr/share/doc/haskell-rsa/html/RSA.haddock
haddock-html:         /usr/share/doc/haskell-rsa/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rsa-2.4.1-261.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-rsa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 RSA
version:              2.4.1
visibility:           public
id:                   RSA-2.4.1-LV5qhxMUChaIy51PgyauiV
key:                  RSA-2.4.1-LV5qhxMUChaIy51PgyauiV
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@galois.com>
author:               Adam Wick <awick@galois.com>
stability:            stable
synopsis:
    Implementation of RSA, using the padding schemes of PKCS#1 v2.1.

description:
    This library implements the RSA encryption and signature
    algorithms for arbitrarily-sized ByteStrings. While the
    implementations work, they are not necessarily the fastest ones
    on the planet. Particularly key generation. The algorithms
    included are based of RFC 3447, or the Public-Key Cryptography
    Standard for RSA, version 2.1 (a.k.a, PKCS#1 v2.1).

category:             Cryptography, Codec
abi:                  ba89a65991b9ad38f4ad1d4ff2d30c91
exposed:              True
exposed-modules:
    Codec.Crypto.RSA Codec.Crypto.RSA.Exceptions Codec.Crypto.RSA.Pure

import-dirs:          /usr/lib/ghc-9.4.8/site-local/RSA-2.4.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/RSA-2.4.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/RSA-2.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rsa
hs-libraries:         HSRSA-2.4.1-LV5qhxMUChaIy51PgyauiV
depends:
    SHA-1.6.4.4-8ksu987L0xnDMFbhBLiacl base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 crypto-api-0.13.3-L9US7GS3I02EI9rbQ94kVv
    crypto-pubkey-types-0.4.3-5Pcjy2m9rZe6LboJvd45XW

haddock-interfaces:   /usr/share/doc/haskell-rsa/html/RSA.haddock
haddock-html:         /usr/share/doc/haskell-rsa/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
